@@ -134,6 +134,7 @@ typedef enum globus_gfs_command_type_e
     GLOBUS_GFS_CMD_UPAS,
     GLOBUS_GFS_CMD_UPRT,
     GLOBUS_GFS_CMD_STORATTR,
+    GLOBUS_GFS_CMD_WHOAMI,
     
     GLOBUS_GFS_MIN_CUSTOM_CMD = 4096
 } globus_gfs_command_type_t;
@@ -1060,9 +1061,9 @@ typedef enum
 } globus_gfs_op_info_param_t;
 
 /* query op_info for parameters
- * query paramters listed in the globus_gfs_op_info_param_t enum.
+ * query parameters listed in the globus_gfs_op_info_param_t enum.
  * the varargs should be populated with variables of the correct type to hold
- * the returning paramters for the requested param type.
+ * the returning parameters for the requested param type.
  * 
 */
 globus_result_t
@@ -1833,6 +1834,21 @@ globus_gfs_ipc_handle_connect(
     globus_gfs_ipc_error_callback_t     error_cb,
     void *                              error_user_arg);
 
+globus_result_t
+globus_gfs_ipc_handle_connect_ex(
+    globus_gfs_session_info_t *         session_info,
+    globus_gfs_ipc_open_callback_t      cb,
+    void *                              user_arg,
+    globus_gfs_ipc_error_callback_t     error_cb,
+    void *                              error_user_arg,
+    globus_bool_t                       secure_ipc,
+    gss_cred_id_t                       cred,
+    const char                         *auth_mode,
+    const char                         *subject,
+    time_t                              connect_timeout,
+    time_t                              idle_timeout,
+    globus_bool_t                       inetd);
+
 globus_result_t
 globus_gfs_ipc_handle_obtain(
     globus_gfs_session_info_t *         session_info,
